var powerbi;
(function (powerbi) {
    var visuals;
    (function (visuals) {
        var LongTextViewer1453740445633;
        (function (LongTextViewer1453740445633) {
            LongTextViewer1453740445633.textScrollProps = {
                textColor: { objectName: 'TextScrollDetail', propertyName: 'fill1' },
                textFontSize: { objectName: 'TextScrollDetail', propertyName: 'fontSize' }
            };
            var LongTextViewer = (function () {
                function LongTextViewer() {
                }
                LongTextViewer.converter = function (dataView, colors) {
                    var dataElements = [];
                    if (dataView) {
                        var table = dataView.table;
                        if (table) {
                            var rows = table.rows;
                            if (rows && rows.length > 0) {
                                for (var i = 0; i < rows.length; i++) {
                                    dataElements.push({
                                        category: '',
                                        value: rows[i][0]
                                    });
                                }
                            }
                        }
                    }
                    return dataElements;
                };
                /** This is called once when the visual is initialially created */
                LongTextViewer.prototype.init = function (options) {
                    this.colorPalette = options.style.colorPalette.dataColors;
                    // element is the element in which your visual will be hosted.
                    this.divCanvas = d3.select(options.element.get(0)).append('div');
                    this.divCanvas.style({ 'overflow': 'auto', 'overflow-x': 'hidden' });
                    this.divContainer = this.divCanvas.append('div');
                };
                /** Update is called for data updates, resizes & formatting changes */
                LongTextViewer.prototype.update = function (options) {
                    this.divCanvas.style({ 'width': options.viewport.width + 'px', 'height': options.viewport.height + 'px', 'overflow-x': 'hidden' });
                    this.divContainer.style({ 'width': options.viewport.width });
                    var dataViews = options.dataViews;
                    if (!dataViews)
                        return;
                    this.dataView = options.dataViews[0];
                    var viewModel = LongTextViewer.converter(dataViews[0], this.colorPalette);
                    var textColor;
                    var textFontSize;
                    if (this.getTextColor(this.dataView)) {
                        textColor = this.getTextColor(this.dataView).solid.color;
                    }
                    textFontSize = this.getTextSize(this.dataView);
                    if (!textFontSize) {
                        textFontSize = 12;
                    }
                    var texts = this.divContainer.selectAll('.textScrollVis').data(viewModel);
                    texts.enter().append('p').classed('textScrollVis', true);
                    texts.style({ "font-size": textFontSize + "pt" }).style({ "color": textColor }).style("text-anchor", "middle").style('width', options.viewport.width).text(function (d) {
                        return d.value;
                    });
                    texts.exit().remove();
                };
                LongTextViewer.prototype.enumerateObjectInstances = function (options) {
                    var enumeration = new visuals.ObjectEnumerationBuilder();
                    switch (options.objectName) {
                        case 'TextScrollDetail':
                            enumeration.pushInstance({
                                objectName: 'TextScrollDetail',
                                displayName: 'Text',
                                selector: null,
                                properties: {
                                    fill1: this.getTextColor(this.dataView),
                                    fontSize: this.getTextSize(this.dataView),
                                }
                            });
                            break;
                    }
                    return enumeration.complete();
                };
                LongTextViewer.prototype.getTextColor = function (dataView) {
                    if (dataView && dataView.metadata && dataView.metadata.objects) {
                        if (dataView.metadata.objects && dataView.metadata.objects.hasOwnProperty('TextScrollDetail')) {
                            var FTitle = dataView.metadata.objects['TextScrollDetail'];
                            if (FTitle && FTitle.hasOwnProperty('fill1')) {
                                return FTitle['fill1'];
                            }
                        }
                        else {
                            return dataView && dataView.metadata && powerbi.DataViewObjects.getValue(dataView.metadata.objects, LongTextViewer1453740445633.textScrollProps.textColor, { solid: { color: '#333333' } });
                        }
                    }
                    return dataView && dataView.metadata && powerbi.DataViewObjects.getValue(dataView.metadata.objects, LongTextViewer1453740445633.textScrollProps.textColor, { solid: { color: '#333333' } });
                };
                LongTextViewer.prototype.getTextSize = function (dataView) {
                    if (dataView && dataView.metadata && dataView.metadata.objects) {
                        if (dataView.metadata.objects && dataView.metadata.objects.hasOwnProperty('TextScrollDetail')) {
                            var FTitle = dataView.metadata.objects['TextScrollDetail'];
                            if (FTitle && FTitle.hasOwnProperty('fontSize')) {
                                return FTitle['fontSize'];
                            }
                        }
                        else {
                            return 12;
                        }
                    }
                    return 12;
                };
                LongTextViewer.capabilities = {
                    // This is what will appear in the 'Field Wells' in reports
                    dataRoles: [
                        {
                            name: 'Category',
                            kind: powerbi.VisualDataRoleKind.GroupingOrMeasure,
                            displayName: 'Category',
                        }
                    ],
                    // This tells power bi how to map your roles above into the dataview you will receive
                    dataViewMappings: [{
                        conditions: [
                            { 'Category': { max: 1 } },
                        ],
                        categorical: {
                            categories: {
                                for: { in: 'Category' },
                                dataReductionAlgorithm: { top: {} }
                            },
                            rowCount: { preferred: { min: 1 } }
                        }
                    }],
                    // Objects light up the formatting pane
                    objects: {
                        general: {
                            displayName: powerbi.data.createDisplayNameGetter('Visual_General'),
                            properties: {
                                formatString: {
                                    type: { formatting: { formatString: true } },
                                },
                            },
                        },
                        TextScrollDetail: {
                            displayName: 'Text',
                            properties: {
                                fill1: {
                                    displayName: 'Font color',
                                    description: 'Font color of visual',
                                    type: { fill: { solid: { color: true } } }
                                },
                                fontSize: {
                                    displayName: 'Text Size',
                                    description: 'Font size of visual',
                                    type: { formatting: { fontSize: true } }
                                }
                            }
                        }
                    }
                };
                return LongTextViewer;
            })();
            LongTextViewer1453740445633.LongTextViewer = LongTextViewer;
        })(LongTextViewer1453740445633 = visuals.LongTextViewer1453740445633 || (visuals.LongTextViewer1453740445633 = {}));
    })(visuals = powerbi.visuals || (powerbi.visuals = {}));
})(powerbi || (powerbi = {}));
var powerbi;
(function (powerbi) {
    var visuals;
    (function (visuals) {
        var plugins;
        (function (plugins) {
            plugins.LongTextViewer1453740445633 = {
                name: 'LongTextViewer1453740445633',
                class: 'LongTextViewer1453740445633',
                capabilities: powerbi.visuals.LongTextViewer1453740445633.LongTextViewer.capabilities,
                custom: true,
                create: function (options) { return new powerbi.visuals.LongTextViewer1453740445633.LongTextViewer(options); },
                apiVersion: null
            };
        })(plugins = visuals.plugins || (visuals.plugins = {}));
    })(visuals = powerbi.visuals || (powerbi.visuals = {}));
})(powerbi || (powerbi = {}));
